<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AddFxContextMenu</name>
    <message>
        <source>Insert FX</source>
        <translation>Insérer un Effet Spécial</translation>
    </message>
    <message>
        <source>Add FX</source>
        <translation>Ajouter un Effet Spécial</translation>
    </message>
    <message>
        <source>Replace FX</source>
        <translation>Remplacer un Effet Spécial</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insérer</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
</context>
<context>
    <name>AddWordButton</name>
    <message>
        <source>Character</source>
        <translation>Caractère</translation>
    </message>
    <message>
        <source>Part</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suffix</source>
        <translation>Suffixe</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Add New Word for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdjustPaletteDialog</name>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>Adapter le Niveau Actuel à cette palette</translation>
    </message>
    <message>
        <source>Tolerance</source>
        <translation>Tolérance</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>CameraPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>&amp;Réinitialiser le Centre</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>&amp;Activer</translation>
    </message>
</context>
<context>
    <name>CameraSettingsWidget</name>
    <message>
        <source>Width:</source>
        <translation type="vanished">Largeur:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="vanished">Hauteur:</translation>
    </message>
    <message>
        <source>AR:</source>
        <translation type="vanished">AR:</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>XDpi:</source>
        <translation type="vanished">XDpi:</translation>
    </message>
    <message>
        <source>YDpi:</source>
        <translation type="vanished">YDpi:</translation>
    </message>
    <message>
        <source>Use Current Level Settings</source>
        <translation>Utiliser les paramètres du niveau courant</translation>
    </message>
    <message>
        <source>Bad camera preset</source>
        <translation>Mauvais préréglages de la caméra</translation>
    </message>
    <message>
        <source>&apos;%1&apos; doesn&apos;t seem a well formed camera preset. 
Possibly the preset file has been corrupted</source>
        <translation>&apos;%1&apos; ne semble pas un préréglage de camera bien formé.
 Peut-être le fichier des préréglages a été corrompu.</translation>
    </message>
    <message>
        <source>Preset name</source>
        <translation>Nom du préréglage</translation>
    </message>
    <message>
        <source>Enter the name for %1</source>
        <translation>Entrez le nom de %1</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force Squared Pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error : Preset Name is Invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The preset name must not use &apos;,&apos;(comma).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A/R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished">&lt;custom&gt;</translation>
    </message>
</context>
<context>
    <name>ChannelHisto</name>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RGBA</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CleanupCameraSettingsWidget</name>
    <message>
        <source>Closest:</source>
        <translation type="vanished">Closest:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="vanished">E/O:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="vanished">Y:</translation>
    </message>
    <message>
        <source>DPI:</source>
        <translation type="vanished">DPI:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Nom:</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation type="vanished">Chemin:</translation>
    </message>
    <message>
        <source>Field settings</source>
        <translation type="vanished">Réglages de Field</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>Resulting Level Info</source>
        <translation type="vanished">Informations de niveau résultant</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColumnPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>&amp;Réinitialiser le Centre</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">&amp;Ouvrir le Sub-xsheet</translation>
    </message>
</context>
<context>
    <name>ComboHistoRGBLabel</name>
    <message>
        <source>R:%1 G:%2 B:%3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComboHistogram</name>
    <message>
        <source>Picked Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average Color (Ctrl + Drag)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
</context>
<context>
    <name>DVGui</name>
    <message>
        <source>OK</source>
        <translation type="vanished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Annuler</translation>
    </message>
</context>
<context>
    <name>DVGui::CleanupColorField</name>
    <message>
        <source>Brightness:</source>
        <translation>Luminosité:</translation>
    </message>
    <message>
        <source>Contrast:</source>
        <translation>Contraste:</translation>
    </message>
    <message>
        <source>Color Threshold</source>
        <translation type="vanished">Seuil de la Couleur:</translation>
    </message>
    <message>
        <source>White Threshold</source>
        <translation type="vanished">Seuil du Blanc:</translation>
    </message>
    <message>
        <source>H Range</source>
        <translation>Intervalle de Teinte:</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Épaisseur de la Ligne:</translation>
    </message>
    <message>
        <source>Color Thres</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White Thres</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ColorField</name>
    <message>
        <source>R:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>G:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation type="unfinished">Gras</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished">Italique</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished">Soulignement</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation type="unfinished">Aligner à Gauche</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation type="unfinished">Aligner au Centre</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation type="unfinished">Aligner à Droite</translation>
    </message>
</context>
<context>
    <name>DVGui::FileField</name>
    <message>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
</context>
<context>
    <name>DVGui::LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="unfinished">Un nom de fichier ne peut pas contenir l&apos;une des chracters suivants: / \: * &quot;|?.</translation>
    </message>
</context>
<context>
    <name>DVGui::ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="obsolete">Toonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="obsolete">Toonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation type="unfinished">Il est possible de charger seulement des fichiers TNZBAT.</translation>
    </message>
</context>
<context>
    <name>DVGui::ValidatedChoiceDialog</name>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Apply to All</source>
        <translation>Appliquer à Tous</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation type="vanished">Gras</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Italique</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="vanished">Soulignement</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation type="vanished">Aligner à Gauche</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation type="vanished">Aligner au Centre</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation type="vanished">Aligner à Droite</translation>
    </message>
</context>
<context>
    <name>EaseInOutSegmentPage</name>
    <message>
        <source>Ease In:</source>
        <translation>Ease In:</translation>
    </message>
    <message>
        <source>Ease Out:</source>
        <translation>Ease Out:</translation>
    </message>
</context>
<context>
    <name>EasyInputArea</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Alerte</translation>
    </message>
    <message>
        <source>%1 is already registered</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileField</name>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
</context>
<context>
    <name>FileSegmentPage</name>
    <message>
        <source>File Path:</source>
        <translation>Chemin du fichier:</translation>
    </message>
    <message>
        <source>Column:</source>
        <translation>Colonne:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Unité:</translation>
    </message>
</context>
<context>
    <name>FlipConsole</name>
    <message>
        <source> FPS </source>
        <translation>IPS</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Instantané</translation>
    </message>
    <message>
        <source>Define Sub-camera</source>
        <translation>Définir une Sous-Caméra</translation>
    </message>
    <message>
        <source>Background Colors</source>
        <translation>Couleur de Fond</translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation>Images par Seconde</translation>
    </message>
    <message>
        <source>Playback Controls</source>
        <translation>Contrôles de Lecture</translation>
    </message>
    <message>
        <source>Color Channels</source>
        <translation>Couleurs des Couches</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Définir une Clé</translation>
    </message>
    <message>
        <source>Histogram</source>
        <translation>Histogramme</translation>
    </message>
    <message>
        <source>&amp;Save Images</source>
        <translation>&amp;Enregistrer les Images</translation>
    </message>
    <message>
        <source>&amp;Snapshot</source>
        <translation>&amp;Instantané</translation>
    </message>
    <message>
        <source>&amp;Compare to Snapshot</source>
        <translation>&amp;Comparer à l&apos;Instantané</translation>
    </message>
    <message>
        <source>&amp;Define Sub-camera</source>
        <translation>&amp;Définir une Sous-Caméra</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>&amp;Fond Blanc</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>&amp;Fond Noir</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>&amp;Fond à Damier</translation>
    </message>
    <message>
        <source>Set the playback frame rate</source>
        <translation>Régle l&apos;IPS de lecture</translation>
    </message>
    <message>
        <source>&amp;First Frame</source>
        <translation>&amp;Première Image</translation>
    </message>
    <message>
        <source>&amp;Previous Frame</source>
        <translation>&amp;Image Précédente</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauser</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Exécuter</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>Boucler</translation>
    </message>
    <message>
        <source>&amp;Next frame</source>
        <translation>&amp;Image Suivante</translation>
    </message>
    <message>
        <source>&amp;Last Frame</source>
        <translation>&amp;Dernière Image</translation>
    </message>
    <message>
        <source>Red Channel</source>
        <translation>Couche Rouge</translation>
    </message>
    <message>
        <source>Red Channel in Grayscale</source>
        <translation>Couche Rouge en Niveaux de Gris</translation>
    </message>
    <message>
        <source>Green Channel</source>
        <translation>Couche Vert</translation>
    </message>
    <message>
        <source>Green Channel in Grayscale</source>
        <translation>Couche Vert en Niveaux de Gris</translation>
    </message>
    <message>
        <source>Blue Channel</source>
        <translation>Couche Bleu</translation>
    </message>
    <message>
        <source>Blue Channel in Grayscale</source>
        <translation>Couche Bleu en Niveaux de Gris</translation>
    </message>
    <message>
        <source>Alpha Channel</source>
        <translation>Couche Cache</translation>
    </message>
    <message>
        <source>&amp;Soundtrack </source>
        <translation>&amp;Bande Sonore </translation>
    </message>
    <message>
        <source>&amp;Histogram</source>
        <translation>&amp;Histogramme</translation>
    </message>
    <message>
        <source> FPS	</source>
        <translation>IPS</translation>
    </message>
    <message>
        <source> Frame  </source>
        <translation type="vanished">Image</translation>
    </message>
    <message>
        <source>Set the current frame</source>
        <translation>Définis l&apos;image courante</translation>
    </message>
    <message>
        <source>Drag to play the animation</source>
        <translation>Glisse pour executer l&apos;animation</translation>
    </message>
    <message>
        <source>Define Loading Box</source>
        <translation>Definir le Cadre de Chargement</translation>
    </message>
    <message>
        <source>Use Loading Box</source>
        <translation>Utiliser le Cadre de Chargement</translation>
    </message>
    <message>
        <source>&amp;Define Loading Box</source>
        <translation>&amp;Definir le Cadre de Chargement</translation>
    </message>
    <message>
        <source>&amp;Use Loading Box</source>
        <translation>&amp;Utiliser le Cadre de Chargement</translation>
    </message>
    <message>
        <source>Display Areas as Filled</source>
        <translation>Afficher les Zones comme Rempli</translation>
    </message>
    <message>
        <source>&amp;Display Areas as Filled</source>
        <translation>Display Areas as Filled</translation>
    </message>
    <message>
        <source>&amp;Locator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Viewer Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Flip Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Flip Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reset View</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontParamField</name>
    <message>
        <source>Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrameNavigator</name>
    <message>
        <source>Previous Frame</source>
        <translation>Image Précédente</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation>Image Suivante</translation>
    </message>
</context>
<context>
    <name>FunctionExpressionSegmentPage</name>
    <message>
        <source>Expression:</source>
        <translation>Expression:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Unité de Mesure:</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>Il ya une référence circulaire dans la définition de l&apos;interpolation.</translation>
    </message>
</context>
<context>
    <name>FunctionPanel</name>
    <message>
        <source>Link Handles</source>
        <translation>Lier les Poignées</translation>
    </message>
    <message>
        <source>Unlink Handles</source>
        <translation>Séparer les Poignées</translation>
    </message>
    <message>
        <source>Reset Handles</source>
        <translation>Réinitialiser les Poignées</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Définir une Clé</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation>Activer le Cycle</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation>Deactiver le Cycle</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>Interpolation Linéaire</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>Interpolation Speed In / Speed Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>Interpolation Ease In / Ease Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>Interpolation Ease In / Ease Out (%)</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>Interpolation Exponentielle</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>Interpolation par Expression</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>Interpolation par Fichier </translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>Interpolation Constante</translation>
    </message>
    <message>
        <source>Fit Selection</source>
        <translation>Adapter à la Sélection</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation>Adapter</translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation>Interpolation par Forme Similaire</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation>Pas 1</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation>Pas 2</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation>Pas 3</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation>Pas 4</translation>
    </message>
    <message>
        <source>Function Curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame Based</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Curve Shape</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSegmentViewer</name>
    <message>
        <source>Linear</source>
        <translation>Linéaire</translation>
    </message>
    <message>
        <source>Speed In / Speed Out</source>
        <translation>Speed In / Speed Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out</source>
        <translation>Ease In / Ease Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out %</source>
        <translation>Ease In / Ease Out %</translation>
    </message>
    <message>
        <source>Exponential</source>
        <translation>Exponentielle</translation>
    </message>
    <message>
        <source>Expression</source>
        <translation>Expression</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>Constant</source>
        <translation>Constante</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">Intervalle:</translation>
    </message>
    <message>
        <source>Interpolation:</source>
        <translation>Interpolation:</translation>
    </message>
    <message>
        <source>Step:</source>
        <translation type="vanished">Pas:</translation>
    </message>
    <message>
        <source>Similar Shape</source>
        <translation>Forme Similaire</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Appliquer</translation>
    </message>
    <message>
        <source>&lt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> &gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Const</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Similar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>????</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSelection</name>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation type="unfinished">Il ya une référence circulaire dans la définition de l&apos;interpolation.</translation>
    </message>
</context>
<context>
    <name>FunctionSheet</name>
    <message>
        <source>Function Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSheetCellViewer</name>
    <message>
        <source>Delete Key</source>
        <translation>Supprimer la Clé</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Définir une Clé</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>Interpolation Linéaire</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>Interpolation Speed In / Speed Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>Interpolation Ease In / Ease Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>Interpolation Ease In / Ease Out (%)</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>Interpolation par Expression</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>Interpolation par Fichier </translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>Interpolation Constante</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>Interpolation Exponentielle</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation type="vanished">Pas 1</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation type="vanished">Pas 2</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation type="vanished">Pas 3</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation type="vanished">Pas 4</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation type="unfinished">Activer le Cycle</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation type="unfinished">Deactiver le Cycle</translation>
    </message>
    <message>
        <source>Show Inbetween Values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Inbetween Values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation type="unfinished">Interpolation par Forme Similaire</translation>
    </message>
</context>
<context>
    <name>FunctionToolbar</name>
    <message>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <source>&amp;Function Editor Toggle</source>
        <translation type="vanished">&amp;Toggle de l&apos;Éditeur de Fonctions</translation>
    </message>
    <message>
        <source>&amp;Open Function Curve Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionTreeModel</name>
    <message>
        <source>Stage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plastic Skeleton</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionTreeView</name>
    <message>
        <source>Save Curve</source>
        <translation>Enregistrer la Courbe</translation>
    </message>
    <message>
        <source>Load Curve</source>
        <translation>Charger une Courbe</translation>
    </message>
    <message>
        <source>Export Data</source>
        <translation>Exporter les Données</translation>
    </message>
    <message>
        <source>Show Animated Only</source>
        <translation>Afficher Uniquement les Animés </translation>
    </message>
    <message>
        <source>Show All</source>
        <translation>Afficher Tous</translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxColumnPainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Déconnecter de l&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connecter à l&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>&amp;Coller Ajoutant</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Preview</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">&amp;Ouvrir le Sub-xsheet</translation>
    </message>
    <message>
        <source>&amp;Uncache Fx</source>
        <translation>&amp;Mettre en Cache l&apos;Effet Spécial</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>&amp;Enlever de la Cache l&apos;Effet Spécial</translation>
    </message>
</context>
<context>
    <name>FxOutputPainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>&amp;Activer</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>&amp;Ouvrir le Groupe</translation>
    </message>
    <message>
        <source>&amp;Paste Replace</source>
        <translation>&amp;Coller Remplaçant</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>&amp;Coller Ajoutant</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Déconnecter de l&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connecter à l&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Create Linked FX</source>
        <translation>&amp;Créer un Effet Spécial Lié </translation>
    </message>
    <message>
        <source>&amp;Unlink</source>
        <translation>&amp;Séparer</translation>
    </message>
    <message>
        <source>&amp;Make Macro FX</source>
        <translation>&amp;Créer un Effect Macro</translation>
    </message>
    <message>
        <source>&amp;Explode Macro FX</source>
        <translation>&amp;Exploser l&apos; Effect Macro</translation>
    </message>
    <message>
        <source>&amp;Open Macro FX</source>
        <translation>&amp;Ouvrir l&apos; Effect Macro</translation>
    </message>
    <message>
        <source>&amp;Save As Preset...</source>
        <translation>&amp;Enregistrer Comme Paramètre Prédéfini...</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Preview</translation>
    </message>
    <message>
        <source>&amp;Uncache FX</source>
        <translation>&amp;Enlever de la Cache l&apos;Effet Spécial</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>&amp;Mettre en Cache l&apos;Effet Spécial</translation>
    </message>
</context>
<context>
    <name>FxPalettePainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Déconnecter de l&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connecter à l&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Preview</translation>
    </message>
</context>
<context>
    <name>FxSchematicLink</name>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>&amp;Paste Insert</source>
        <translation>&amp;Coller Insérant</translation>
    </message>
</context>
<context>
    <name>FxSchematicOutputNode</name>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxSchematicPort</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Déconnecter de l&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connecter à l&apos;Xsheet</translation>
    </message>
</context>
<context>
    <name>FxSchematicScene</name>
    <message>
        <source>Cannot Paste Insert a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Il n&apos;est pas possible de Coller Insérant une sélection de nœuds FX deconnectés.
Sélectionnez les nœuds FX et les liens connexes avant de copier ou couper la sélection que vous souhaitez coller.</translation>
    </message>
    <message>
        <source>Cannot Paste Add a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Il n&apos;est pas possible de Coller Ajoutant une sélection de nœuds FX deconnectés.
Sélectionnez les nœuds FX et les liens connexes avant de copier ou couper la sélection que vous souhaitez coller.</translation>
    </message>
    <message>
        <source>Cannot Paste Replace a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Il n&apos;est pas possible de Coller Remplaçant une sélection de nœuds FX deconnectés.
Sélectionnez les nœuds FX et les liens connexes avant de copier ou couper la sélection que vous souhaitez coller.</translation>
    </message>
</context>
<context>
    <name>FxSchematicXSheetNode</name>
    <message>
        <source>XSheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxSettings</name>
    <message>
        <source>&amp;Camera Preview</source>
        <translation>&amp;Preview de Camera</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Preview</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>&amp;Fond Blanc</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>&amp;Fond Noir</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>&amp;Fond à Damier</translation>
    </message>
    <message>
        <source> : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fx Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxXSheetPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation>&amp;Coller Ajoutant</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Preview</translation>
    </message>
    <message>
        <source>XSheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GroupPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>&amp;Ouvrir le Groupe</translation>
    </message>
</context>
<context>
    <name>Histogram</name>
    <message>
        <source>Logarithmic Scale</source>
        <translation>Echelle Logarithmique</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="unfinished">Valeur</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoViewer</name>
    <message>
        <source>File Info</source>
        <translation>Infos sur le Fichier</translation>
    </message>
</context>
<context>
    <name>KeyframeNavigator</name>
    <message>
        <source>Previous Key</source>
        <translation>Clé Précédente</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Définir une Clé</translation>
    </message>
    <message>
        <source>Next Key</source>
        <translation>Clé Suivante</translation>
    </message>
</context>
<context>
    <name>LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="vanished">Un nom de fichier ne peut pas contenir l&apos;une des chracters suivants: / \: * &quot;|?.</translation>
    </message>
</context>
<context>
    <name>NewWordDialog</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
    <message>
        <source>Enter new word</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageViewer</name>
    <message>
        <source>Toggle Link to Studio Palette</source>
        <translation type="vanished">Activer/Désactiver le Lien à la Palette de Studio</translation>
    </message>
    <message>
        <source>Remove Reference to Studio Palette</source>
        <translation type="vanished">Suppression de la référence à la Palette de Studio</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation type="vanished">Nouveau Style</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation type="vanished">Nouvelle Page</translation>
    </message>
</context>
<context>
    <name>PaletteViewer</name>
    <message>
        <source>&amp;Save Palette As</source>
        <translation>&amp;Enregistrer la Palette sous...</translation>
    </message>
    <message>
        <source>&amp;Save Palette</source>
        <translation>&amp;Enregistrer la Palette</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails View</source>
        <translation>&amp;Affichage à Petites Vignettes</translation>
    </message>
    <message>
        <source>&amp;Large Thumbnails View</source>
        <translation>&amp;Affichage à Grandes Vignettes</translation>
    </message>
    <message>
        <source>&amp;List View</source>
        <translation>&amp;Affichage à Liste</translation>
    </message>
    <message>
        <source>&amp;New Page</source>
        <translation>&amp;Nouvelle Page</translation>
    </message>
    <message>
        <source>&amp;New Style</source>
        <translation>&amp;Nouveau Style </translation>
    </message>
    <message>
        <source>&amp;Move Palette</source>
        <translation>&amp;Déplacer la Palette</translation>
    </message>
    <message>
        <source>Color Model: </source>
        <translation type="vanished">Modèle de Coleur:</translation>
    </message>
    <message>
        <source>&amp;Palette Gizmo</source>
        <translation>Palette Gizmo</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nouvelle Page</translation>
    </message>
    <message>
        <source>Delete Page</source>
        <translation>Supprimer la Page</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>Palette</translation>
    </message>
    <message>
        <source>Level Palette: </source>
        <translation>Palette du Niveau: </translation>
    </message>
    <message>
        <source>Cleanup Palette</source>
        <translation>Palette de Nettoyage </translation>
    </message>
    <message>
        <source>Studio Palette</source>
        <translation>Palette de Studio</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails With Name View</source>
        <translation type="vanished">Petites vignettes avec la vue par nom</translation>
    </message>
    <message>
        <source>Lock Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Lock Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Medium Thumbnails View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StudioPalette Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Both Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>     (Color Model: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PaletteViewerGUI::PageViewer</name>
    <message>
        <source>- No Styles -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Style</source>
        <translation type="unfinished">Nouveau Style</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation type="unfinished">Nouvelle Page</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PalettesScanPopup</name>
    <message>
        <source>Search for Palettes</source>
        <translation>Rechercher les Palettes</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>&lt;files&gt;</source>
        <translation>&lt;fichiers&gt;</translation>
    </message>
</context>
<context>
    <name>ParamViewer</name>
    <message>
        <source>Swatch Viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ParamsPageSet</name>
    <message>
        <source>Fx Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PegbarPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>&amp;Réinitialiser le Centre</translation>
    </message>
</context>
<context>
    <name>PlaneViewer</name>
    <message>
        <source>Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PointParamField</name>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">Toonz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Alerte</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critique</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Styles you are going to delete are used to paint lines and areas in the animation level.
</source>
        <translation>Les styles que vous allez supprimer sont utilisés pour peindre des lignes et des zones dans le niveau d&apos;animation.
</translation>
    </message>
    <message>
        <source>How do you want to proceed?</source>
        <translation>Comment voulez-vous procéder?</translation>
    </message>
    <message>
        <source>Delete Styles Only</source>
        <translation>Supprimer Uniquement les Styles </translation>
    </message>
    <message>
        <source>Delete Styles, Lines and Areas</source>
        <translation>Supprimer les Styles, les Lignes et les Zones</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Cannot premultiply the selected file.</source>
        <translation>Il n&apos;est pas possible de prémultiplier le fichier sélectionné.</translation>
    </message>
    <message>
        <source>Cannot premultiply a vector-based level.</source>
        <translation>Il n&apos;est pas possible de prémultiplier un niveau vectoriel.</translation>
    </message>
    <message>
        <source>Level %1 premultiplied.</source>
        <translation>Niveau %1 prémultiplié.</translation>
    </message>
    <message>
        <source>Frame %1 : conversion failed!</source>
        <translation>Frame %1: la conversion a échoué!</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>Palette</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Enregistrer</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="vanished">Jeter</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">Non</translation>
    </message>
    <message>
        <source>Stage Schematic</source>
        <translation>Schématique de Scène</translation>
    </message>
    <message>
        <source>FX Schematic</source>
        <translation>Schématique des Effets Spéciaux</translation>
    </message>
    <message>
        <source>Fx Schematic</source>
        <translation type="vanished">Schématique des Effets Spéciaux</translation>
    </message>
    <message>
        <source>Save Motion Path</source>
        <translation>Enregistrer la Trajectoire</translation>
    </message>
    <message>
        <source>Motion Path files (*.mpath)</source>
        <translation>Fichiers de Trajectoire (*.mpath)</translation>
    </message>
    <message>
        <source>Load Motion Path</source>
        <translation>Charger une Trajectoire</translation>
    </message>
    <message>
        <source>Can&apos;t paste styles there</source>
        <translation>Il n&apos;est pas possible de coller styles selon la sélection courante.</translation>
    </message>
    <message>
        <source>Can&apos;t modify color #0</source>
        <translation>Il n&apos;est pas possible de modifier la couleur #0</translation>
    </message>
    <message>
        <source>There are more cut/copied styles than selected. Paste anyway (adding styles)?</source>
        <translation>Il y a plus de styles coupés/copiés que de styles sélectionnés. Coller de toute façon en ajoutant des styles?</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>For further information visit </source>
        <translation type="vanished">Pour plus d&apos;informations visitez</translation>
    </message>
    <message>
        <source>Fullpath:     </source>
        <translation>Chemin du fichier:</translation>
    </message>
    <message>
        <source>File Type:    </source>
        <translation>Type de Fichier:</translation>
    </message>
    <message>
        <source>Frames:       </source>
        <translation>Images:</translation>
    </message>
    <message>
        <source>Owner:        </source>
        <translation>Propriétaire:</translation>
    </message>
    <message>
        <source>Size:         </source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Created:      </source>
        <translation>Création:</translation>
    </message>
    <message>
        <source>Modified:     </source>
        <translation>Modification:</translation>
    </message>
    <message>
        <source>Last Access:  </source>
        <translation>Dernier Accès:</translation>
    </message>
    <message>
        <source>Image Size:   </source>
        <translation>Taille de l&apos;Image:</translation>
    </message>
    <message>
        <source>SaveBox:      </source>
        <translation>SaveBox:</translation>
    </message>
    <message>
        <source>Bits/Sample:  </source>
        <translation>Cits par Couche:</translation>
    </message>
    <message>
        <source>Sample/Pixel: </source>
        <translation>Couches par Pixel:</translation>
    </message>
    <message>
        <source>Dpi:          </source>
        <translation>DPI:</translation>
    </message>
    <message>
        <source>Orientation:  </source>
        <translation>Orientation:</translation>
    </message>
    <message>
        <source>Compression:  </source>
        <translation>Compression:</translation>
    </message>
    <message>
        <source>Quality:      </source>
        <translation>Qualité:</translation>
    </message>
    <message>
        <source>Smoothing:    </source>
        <translation>Smoothing:</translation>
    </message>
    <message>
        <source>Codec:        </source>
        <translation>Codec:</translation>
    </message>
    <message>
        <source>Alpha Channel:</source>
        <translation>Couche Alpha:</translation>
    </message>
    <message>
        <source>Byte Ordering:</source>
        <translation>Ordre des Octets:</translation>
    </message>
    <message>
        <source>H Pos:</source>
        <translation>H Pos:</translation>
    </message>
    <message>
        <source>Palette Pages:</source>
        <translation>Pages de Palette:</translation>
    </message>
    <message>
        <source>Palette Styles:</source>
        <translation>Styles de Palette:</translation>
    </message>
    <message>
        <source>Camera Size:      </source>
        <translation>Taille de Caméra:</translation>
    </message>
    <message>
        <source>Camera Dpi:       </source>
        <translation>DPI de Caméra:</translation>
    </message>
    <message>
        <source>Number of Frames: </source>
        <translation>Nombre d&apos;Images:</translation>
    </message>
    <message>
        <source>Number of Levels: </source>
        <translation>Nombre de Niveaux:</translation>
    </message>
    <message>
        <source>Output Path:      </source>
        <translation>Chemin de Sortie:</translation>
    </message>
    <message>
        <source>Endianness:      </source>
        <translation>Endianness:</translation>
    </message>
    <message>
        <source>It is not possible to delete the style #</source>
        <translation>Il n&apos;est pas possible de supprimer le style #</translation>
    </message>
    <message>
        <source>It is not possible to delete styles #0 and #1.</source>
        <translation>Il n&apos;est pas possible de supprimer les styles #0 et #1.</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;custom&gt;</translation>
    </message>
    <message>
        <source>It is not possible to find the %1 level.</source>
        <translation>Il n&apos;est pas possible de trouver le niveau de %1.</translation>
    </message>
    <message>
        <source>There was an error copying %1</source>
        <translation>Il y avait une erreur de copie de %1</translation>
    </message>
    <message>
        <source>It is not possible to find the level %1</source>
        <translation>Il n&apos;est pas possible de trouver le niveau %1</translation>
    </message>
    <message>
        <source>Length:       </source>
        <translation>Longueur:</translation>
    </message>
    <message>
        <source>Channels: </source>
        <translation>Chaînes:</translation>
    </message>
    <message>
        <source>Sample Rate: </source>
        <translation>Taux d&apos;échantillonnage:</translation>
    </message>
    <message>
        <source>Sample Size:      </source>
        <translation>Taille de l&apos;échantillon:</translation>
    </message>
    <message>
        <source>The file %1 does not exist.</source>
        <translation>Le fichier %1 n&apos;existe pas.</translation>
    </message>
    <message>
        <source>It is not possible to assing a shortcut with modifiers to the visualization commands.</source>
        <translation type="vanished">Il n&apos;est pas possible de attribuer un raccourci avec des modificateurs aux commandes de visualisation.</translation>
    </message>
    <message>
        <source>It is not possible to save the motion path.</source>
        <translation>Il n&apos;est pas possible d&apos;enregistrer la trajectoire de mouvement.</translation>
    </message>
    <message>
        <source>It is not possible to load the motion path.</source>
        <translation>Il n&apos;est pas possible de charger la trajectoire de mouvement.</translation>
    </message>
    <message>
        <source>Toonz 7.1</source>
        <translation type="vanished">Toonz 7.1</translation>
    </message>
    <message>
        <source>The file name cannot be empty or contain any of the following characters: (new line) \ / : * ? &quot; |</source>
        <translation>Le nom du fichier ne peut pas être vide ou contenir l&apos;un des caractères suivants:
 \ /: *? &quot;|</translation>
    </message>
    <message>
        <source>The source image seems not suitable for this kind of conversion</source>
        <translation>L&apos;image source ne semble pas approprié pour ce genre de conversion</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Deletion of Lines and Areas from raster-based levels is not undoable.
Are you sure?</source>
        <translation></translation>
    </message>
    <message>
        <source>Deleting &quot;%1&quot;.
Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Supprimer</translation>
    </message>
    <message>
        <source>Paste Style  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Style  from Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Style  from Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>  to Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color &amp;&amp; Name%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Name%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blend Colors  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Link  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Color from Studio Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Object  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Keyframe  at Frame : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Style   Palette : %1  Style#%2  [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 -&gt; %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ON : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFF : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 : Linear ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 : Linear OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 Key : %2  Frame %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Reference  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It is not possible to assign a shortcut with modifiers to the visualization commands.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to compile m_textureShader.vert.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to compile m_shader.frag.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to add m_shader.vert.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to add m_shader.frag.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to link simple shader: %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to get attribute location of %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to get uniform location of %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Open 3DLUT File.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
It should start with &quot;3DMESH&quot; keyword.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Texture</source>
        <comment>TextureStyleChooserPage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Frame: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>VectorBrushStyleChooserPage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>MyPaintBrushStyleChooserPage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>SpecialStyleChooserPage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>That is a reserved file name and cannot be used.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">Toonz</translation>
    </message>
</context>
<context>
    <name>RgbLinkButtons</name>
    <message>
        <source>Copy RGB : %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swap %1 and %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicViewer</name>
    <message>
        <source>&amp;Fit to Window</source>
        <translation>&amp;Adapter à la Fenêtre</translation>
    </message>
    <message>
        <source>&amp;Focus on Current</source>
        <translation>&amp;Focaliser sur le Courant</translation>
    </message>
    <message>
        <source>&amp;Reorder Nodes</source>
        <translation>&amp;Réorganiser les Noeuds</translation>
    </message>
    <message>
        <source>&amp;Reset Size</source>
        <translation>&amp;Réinitialiser la Taille</translation>
    </message>
    <message>
        <source>&amp;Minimize Nodes</source>
        <translation>&amp;Minimiser les Noeuds</translation>
    </message>
    <message>
        <source>&amp;Maximize Nodes</source>
        <translation>&amp;Maximiser les Nœuds</translation>
    </message>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>&amp;Nouvelle Reglette</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>&amp;Nouvelle Caméra</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>&amp;Nouvelle Trajectoire</translation>
    </message>
    <message>
        <source>&amp;Schematic Toggle</source>
        <translation type="vanished">&amp;Toggle du Schématique</translation>
    </message>
    <message>
        <source>&amp;Swtich output port display mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Toggle node icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Selection Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Hand Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicWindowEditor</name>
    <message>
        <source>&amp;Close Editor</source>
        <translation>&amp;Fermer l&apos;Éditeur</translation>
    </message>
</context>
<context>
    <name>SimilarShapeSegmentPage</name>
    <message>
        <source>Reference Curve:</source>
        <translation>Courbe de Référence:</translation>
    </message>
    <message>
        <source>Frame Offset:</source>
        <translation>Images de Décalage:</translation>
    </message>
    <message>
        <source>There is a syntax error in the definition of the interpolation.</source>
        <translation>Il ya une erreur de syntaxe dans la définition de l&apos;interpolation.</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>Il ya une référence circulaire dans la définition de l&apos;interpolation.</translation>
    </message>
</context>
<context>
    <name>SpecialStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">Couleur plan</translation>
    </message>
</context>
<context>
    <name>SpeedInOutSegmentPage</name>
    <message>
        <source>Speed in:</source>
        <translation type="vanished">Speed in:</translation>
    </message>
    <message>
        <source>Speed out:</source>
        <translation type="vanished">Speed out:</translation>
    </message>
    <message>
        <source>First Speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Handle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>---</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SplinePainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>&amp;Save Motion Path...</source>
        <translation>&amp;Enregistrer la Trajectoire...</translation>
    </message>
    <message>
        <source>&amp;Load Motion Path...</source>
        <translation>&amp;Charger la Trajectoire...</translation>
    </message>
</context>
<context>
    <name>StageSchematicNode</name>
    <message>
        <source>Toggle Autorotate Along Motion Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Link Motion Path to Control Points</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StageSchematicScene</name>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>&amp;Nouvelle Reglette</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>&amp;Nouvelle Trajectoire</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>&amp;Nouveau Caméra</translation>
    </message>
</context>
<context>
    <name>StudioPaletteTreeViewer</name>
    <message>
        <source>This folder is not empty. Delete anyway?</source>
        <translation>Ce dossier n&apos;est pas vide. Supprimer de toute façon?</translation>
    </message>
    <message>
        <source>New Palette</source>
        <translation>Nouvelle Palette</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nouveau Dossier</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Supprimer le Dossier</translation>
    </message>
    <message>
        <source>Load into Current Palette</source>
        <translation>Charger dans la  Palette Courante</translation>
    </message>
    <message>
        <source>Merge to Current Palette</source>
        <translation>Fusionner avec la Palette Courante</translation>
    </message>
    <message>
        <source>Replace with Current Palette</source>
        <translation>Remplacer avec la Palette Courante</translation>
    </message>
    <message>
        <source>Delete Palette</source>
        <translation>Supprimer la Palette</translation>
    </message>
    <message>
        <source>Search for Palettes</source>
        <translation>Rechercher les Palettes</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>Adapter le Niveau Actuel à cette palette</translation>
    </message>
    <message>
        <source>Convert to Studio Palette and Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>the palette &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>the selected palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move %1 to &quot;%2&quot;. Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
    <message>
        <source>The current palette %1
in the studio palette has been modified. Do you want to save your changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Enregistrer</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="unfinished">Jeter</translation>
    </message>
    <message>
        <source>Convert %1 to Studio Palette and Overwrite. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Non</translation>
    </message>
    <message>
        <source>Replacing all selected palettes with the palette &quot;%1&quot;. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replacing the palette &quot;%1&quot; with the palette &quot;%2&quot;. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Convert</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StudioPaletteViewer</name>
    <message>
        <source>&amp;New Folder</source>
        <translation type="vanished">&amp;Nouveau Dossier</translation>
    </message>
    <message>
        <source>&amp;New Palette</source>
        <translation type="vanished">&amp;Nouvelle Palette</translation>
    </message>
    <message>
        <source>&amp;Search for Palettes</source>
        <translation type="vanished">&amp;Rechercher les Palettes</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">&amp;Supprimer</translation>
    </message>
</context>
<context>
    <name>StyleEditor</name>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Apply changes to current style</source>
        <translation>Appliquer les modifications au style courant</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Automatically update style changes</source>
        <translation>Mise à jour automatique des changements de style</translation>
    </message>
    <message>
        <source>Return To Previous Style</source>
        <translation>Retour au Style Précédent</translation>
    </message>
    <message>
        <source>Current Style</source>
        <translation>Style Courant</translation>
    </message>
    <message>
        <source>Plain</source>
        <translation type="vanished">Plaine</translation>
    </message>
    <message>
        <source>Texture</source>
        <translation>Texture</translation>
    </message>
    <message>
        <source>Special</source>
        <translation type="vanished">Spécial</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="vanished">Personalisé</translation>
    </message>
    <message>
        <source>Vector Brush</source>
        <translation>Pinceau Vectorielle</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[CLEANUP]  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[STUDIO]  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[LEVEL]  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show or hide parts of the Color Page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle orientation of the Color Page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Style Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style Editor - No Valid Style Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wheel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HSV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette</source>
        <translation type="unfinished">Palette</translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::ColorChannelControl</name>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::SettingsPage</name>
    <message>
        <source>Autopaint for Lines</source>
        <translation>Couleur Automatique pour les Lignes</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleNameEditor</name>
    <message>
        <source>Name Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">Appliquer</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Editor: # %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply and Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easy Inputs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SwatchViewer</name>
    <message>
        <source>Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TMessageViewer</name>
    <message>
        <source>Errors</source>
        <translation>Erreurs</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>Avertissements</translation>
    </message>
    <message>
        <source>Infos</source>
        <translation type="vanished">Infos</translation>
    </message>
    <message>
        <source> Clear </source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Display:  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TablePainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>Réinitialiser le Centre</translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation type="vanished">Il est possible de charger seulement des fichiers TNZBAT.</translation>
    </message>
</context>
<context>
    <name>VectorBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">Il est impossible de supprimer %1.</translation>
    </message>
</context>
<context>
    <name>WordButton</name>
    <message>
        <source>Remove %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
